Package: photosynthesis
Version: 2.1.5
Date: 2024-11-23
Title: Tools for Plant Ecophysiology & Modeling
Authors@R: c(
    person("Joseph", "Stinziano", email = "josephstinziano@gmail.com", role = "aut", comment = c(ORCID = "0000-0002-7628-4201")),
    person("Cassaundra", "Roback", email = "croback@unm.edu", role = "aut"),
    person("Demi", "Sargent", email = "d.sargent@westernsydney.edu.au", role = "aut"),
    person("Bridget", "Murphy", email = "bridget.murphy@mail.utoronto.ca", role = "aut"),
    person("Patrick", "Hudson", email = "hudson.patrick.j@gmail.com", role = c("aut", "dtc")), 
    person("Chris", "Muir", email = "cdmuir@wisc.edu", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-2555-3878"))
    )
Depends: R (>= 4.0.0), ggplot2 (>= 3.4.0), minpack.lm (>= 1.2-1), units
        (>= 0.6.6)
Imports: checkmate (>= 2.0.0), crayon (>= 1.3.4), dplyr (>= 0.8.5),
        furrr (>= 0.1.0), glue (>= 1.4.0), graphics (>= 4.0.0),
        grDevices (>= 4.0.0), gunit (>= 1.0.2), lifecycle (>= 1.0.0),
        magrittr (>= 1.5.0), methods (>= 3.5.0), nlme (>= 3.1-147),
        progress (>= 1.2.0), purrr (>= 0.3.3), readr (>= 2.0.0), rlang
        (>= 0.4.6), stats (>= 4.0.0), stringr (>= 1.4.0), tealeaves (>=
        1.0.5), utils (>= 4.0.0)
Suggests: brms, broom, future, knitr, rmarkdown, testthat, tibble,
        tidyr, tidyselect
Description: Contains modeling and analytical tools for plant ecophysiology.
    MODELING: Simulate C3 photosynthesis using the Farquhar, von Caemmerer,
    Berry (1980) <doi:10.1007/BF00386231> model as described in Buckley and
    Diaz-Espejo (2015) <doi:10.1111/pce.12459>. It uses units to ensure that
    parameters are properly specified and transformed before calculations.
    Temperature response functions get automatically "baked" into all
    parameters based on leaf temperature following Bernacchi et al. (2002)
    <doi:10.1104/pp.008250>. The package includes boundary layer, cuticular,
    stomatal, and mesophyll conductances to CO2, which each can vary on the
    upper and lower portions of the leaf. Use straightforward functions to
    simulate photosynthesis over environmental gradients such as Photosynthetic
    Photon Flux Density (PPFD) and leaf temperature, or over trait gradients
    such as CO2 conductance or photochemistry. 
    ANALYTICAL TOOLS: Fit ACi (Farquhar et al. (1980) <doi:10.1007/BF00386231>)
    and AQ curves (Marshall & Biscoe (1980) <doi:10.1093/jxb/31.1.29>),
    temperature responses (Heskel et al. (2016) <doi:10.1073/pnas.1520282113>;
    Kruse et al. (2008) <doi:10.1111/j.1365-3040.2008.01809.x>, Medlyn et al.
    (2002) <doi:10.1046/j.1365-3040.2002.00891.x>, Hobbs et al. (2013)
    <doi:10.1021/cb4005029>), respiration in the light (Kok (1956)
    <doi:10.1016/0006-3002(56)90003-8>, Walker & Ort (2015) <doi:10.1111/pce.12562>,
    Yin et al. (2009) <doi:10.1111/j.1365-3040.2009.01934.x>, Yin et al. (2011)
    <doi:10.1093/jxb/err038>), mesophyll conductance (Harley et al. (1992)
    <doi:10.1104/pp.98.4.1429>), pressure-volume curves (Koide et al. (2000)
    <doi:10.1007/978-94-009-2221-1_9>, Sack et al. (2003)
    <doi:10.1046/j.0016-8025.2003.01058.x>, Tyree et al. (1972)
    <doi:10.1093/jxb/23.1.267>), hydraulic vulnerability curves (Ogle et al. (2009)
    <doi:10.1111/j.1469-8137.2008.02760.x>, Pammenter et al. (1998)
    <doi:10.1093/treephys/18.8-9.589>), and tools for running sensitivity
    analyses particularly for variables with uncertainty (e.g. g_mc(), gamma_star(),
    R_d()).
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
VignetteBuilder: knitr
URL: https://github.com/cdmuir/photosynthesis
BugReports: https://github.com/cdmuir/photosynthesis/issues
NeedsCompilation: no
Packaged: 2024-11-24 19:18:24 UTC; cdmuir
Author: Joseph Stinziano [aut] (<https://orcid.org/0000-0002-7628-4201>),
  Cassaundra Roback [aut],
  Demi Sargent [aut],
  Bridget Murphy [aut],
  Patrick Hudson [aut, dtc],
  Chris Muir [aut, cre] (<https://orcid.org/0000-0003-2555-3878>)
Maintainer: Chris Muir <cdmuir@wisc.edu>
Repository: CRAN
Date/Publication: 2024-11-24 19:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 20:29:50 UTC; unix
